This section describes the classes defined in py4xs, and their attributes and methods 
that are important for data processing. More detailed information can be found in the 
docstrings. See also the examples.



